package com.elab.mq.listener;

import com.aliyun.openservices.ons.api.Action;
import com.aliyun.openservices.ons.api.ConsumeContext;
import com.aliyun.openservices.ons.api.Message;
import com.aliyun.openservices.ons.api.MessageListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * 抽象成客户端能够使用的方法
 *
 * @author ： liukx
 * @time ： 2019/4/22 - 18:02
 */
public abstract class AbstractMessageListener implements MessageListener {

    private Logger logger = LoggerFactory.getLogger(getClass());

    /**
     * 客户端关注的topic消息,实现了该方法,消息监听被触发时会与之匹配。
     *
     * @return
     */
    public abstract String topic();

    /**
     * 客户端关注的topic下的tag子类标签
     *
     * @return
     */
    public abstract String tag();

    /**
     * 客户端的业务逻辑实现
     *
     * @param message        消息对象
     * @param consumeContext 消息上下文
     * @return
     */
    public abstract Action consume0(Message message, ConsumeContext consumeContext);

    @Override
    public Action consume(Message message, ConsumeContext consumeContext) {
        logger.debug("消息处理被触发 : " + message.toString());
        Action action = consume0(message, consumeContext);
        logger.debug("消息处理结果 : " + action);
        return action;
    }

}
